@@ -25,7 +25,7 @@ NULL
 #'
 check_type_region <- function(region){
   # load regions
-  data("regions", package = "tabs", envir = environment())
+  utils::data("regions", package = "tabs", envir = environment())
   if_character <- grepl('character',class(region)[1])
   if(if_character) if_character_is_file <- file.exists(region[1]) else if_character_is_file <- FALSE
   if(if_character)
@@ -38,11 +38,11 @@ check_type_region <- function(region){
                                   stringi::stri_trans_general(str = x, id = "Latin-ASCII")),
                              '$'), 
                       regions$name_ascii,ignore.case =TRUE),] %>% 
-          arrange(dataset,region) %>% 
+          dplyr::arrange(dataset,region) %>% 
           dplyr::slice(1))) %>% 
-        dplyr::group_by(dataset,region) %>% 
-        dplyr::mutate(n=n()) %>% 
-        dplyr::arrange(dplyr::desc(n))
+          dplyr::group_by(dataset,region) %>% 
+          dplyr::mutate(n=dplyr::n()) %>% 
+          dplyr::arrange(dplyr::desc(n))
       type <- which_type$region
       dataset <- which_type$dataset
     } else {
@@ -76,11 +76,15 @@ get_ext_island <- function(region, buffer=NULL){ # search in island dataset
   data("regions", package = "tabs", envir = environment())
   
   region_l<- lapply(region, function(x) 
-    regions[grepl(paste0('^',stringi::stri_trans_general(str = x, id = "Latin-ASCII"),'$'),regions$name_ascii,ignore.case =TRUE),'name']
+    regions[grepl(paste0('^',
+                         gsub("([][{}()*+?.\\^$|])", 
+                              "\\\\\\1", 
+                         stringi::stri_trans_general(str = x, id = "Latin-ASCII")),
+                         '$'),regions$name_ascii,ignore.case =TRUE),'name']
   )
   region <- unlist(region_l)
   s<- terra::vect(y[grepl('reference',y)],query=paste0("SELECT unique_id,name,area_km2,coastline_km, plate_id,land_type_id, geom FROM islands 
-                                       WHERE name is not NULL AND lower(name) in ('",paste0(c(tolower(region)), collapse="','"),"') ORDER BY unique_id"))
+                                       WHERE name is not NULL AND lower(name) in ('",paste0(c(gsub("'", "''", tolower(region))), collapse="','"),"') ORDER BY unique_id"))
   if(is.null(buffer)) buffer <- 10000 # default buffer 
   e <- extent_outputs(p=terra::buffer(terra::as.polygons(terra::ext(s),crs=terra::crs(s)),
                                       width=buffer))
@@ -228,6 +232,7 @@ get_ext_mountains <- function(region,buffer=NULL){ # search in mountain dataset
 #' 
 #'
 get_ext_region <- function(region, buffer=NULL, verbose=FALSE){
+  e <- NULL
   if_character <- grepl('character',class(region)[1])
   if(as.numeric(verbose) > 1){message('region is character ',if_character)}
   if(if_character) if_character_is_file <- file.exists(region) else if_character_is_file <- FALSE
@@ -278,7 +283,7 @@ get_ext_region <- function(region, buffer=NULL, verbose=FALSE){
 #' @keywords internal
 #' 
 #'
-get_ext <- function(region=NULL,buffer=buffer,verbose=FALSE){ # from extent coordinates and if no coordinates are given open a pop-up
+get_ext <- function(region=NULL,buffer=NULL,verbose=FALSE){ # from extent coordinates and if no coordinates are given open a pop-up
   is_terra_spatextent <- grepl('SpatExtent',class(region)[1])
   if(as.numeric(verbose) > 1){message('input terra extent ',is_terra_spatextent)}
   is_extent_numeric <- all(class(region) == 'numeric' & length(region) == 4)
@@ -333,6 +338,7 @@ get_ext <- function(region=NULL,buffer=buffer,verbose=FALSE){ # from extent coor
 #' 
 #'
 get_ext_custom <- function(region,buffer=NULL,verbose=FALSE){ # use the extent of the custom provided polygon
+  e <- NULL
   if_character <- grepl('character',class(region)[1])
   if(as.numeric(verbose) > 1){message('region is character ',if_character)}
   if(if_character) if_character_is_file <- file.exists(region) else if_character_is_file <- FALSE
@@ -759,7 +765,7 @@ get_layer <- function(region=NULL,reclabs=NULL,buffer=NULL,verbose=FALSE,aggrega
   if(aggregate){ # if FALSE, aggregate polygons 
     #if(attr(s, 'layer') != 'custom' & attr(s, 'aggregate')==TRUE){
     if(as.numeric(verbose) == 1) message('aggregate shapes, avoid labeling')
-    s <- aggregate(s)
+    s <- terra::aggregate(s)
     s$unique_id <- 1
     s$name <- 'S'
     #}
