@@ -72,6 +72,7 @@ download_link_topo <- function(){ # dataset=c('gebco_2022_sub_ice_topo','gebco_2
   # check for new dataset 
   #url <- paste0('https://www.bodc.ac.uk/data/open_download/gebco/gebco_',Y,'_sub_ice_topo/zip/')
   url <- 'https://uvaauas.figshare.com/ndownloader/files/52652597'
+  #url <- "https://ndownloader.figshare.com/files/52652597"
   # update link if there is no dataset for 2023
   if(httr::http_error(url)){ 
     url <- gsub(Y,as.numeric(Y)-1,url)
@@ -95,7 +96,8 @@ download_link_topo <- function(){ # dataset=c('gebco_2022_sub_ice_topo','gebco_2
 download_link_curve <- function(){
   httr::set_config(httr::config(followlocation=TRUE, ssl_verifypeer = FALSE, ssl_verifyhost = FALSE))
   # check if url exists
-  url <- 'https://figshare.com/ndownloader/articles/20029991'
+  #url <- 'https://figshare.com/ndownloader/articles/20029991'
+  url <- 'https://figshare.com/ndownloader/articles/20029991/versions/1'
   if(httr::HEAD(url)$status == 401){
     url <- paste0(url,'?private_link=18773cb0b573add21388')
   }
@@ -123,7 +125,10 @@ download_link_labs <- function(source=F){
   httr::set_config(httr::config(followlocation=TRUE, ssl_verifypeer = FALSE, ssl_verifyhost = FALSE))
   # check if url exists
   #url <- 'https://uvaauas.figshare.com/ndownloader/files/39361361'
+    
   url <- 'https://uvaauas.figshare.com/ndownloader/files/46942207'
+  #url <- 'https://ndownloader.figshare.com/files/46942207'
+  
   # if(httr::HEAD(url)$status == 502){
   #   url <- paste0(url,'?private_link=d8c204cfda92363b4377')
   # }
@@ -270,7 +275,13 @@ download <- function(path=NULL, name=options()$tabs.datasetNames, autoupdate=FAL
           # download 
           #download.file(url=url[x], temp_file) # download
           
-          bin <- httr::content(httr::GET(url[x],httr::progress()))
+          user_a <- httr::user_agent(
+            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 \
+             (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36")
+
+          bin <- httr::content(httr::GET(url[x],
+                                         user_a,
+                                         httr::progress()))
           # bin <- getBinaryURL(url,opts=list(followlocation=TRUE, ssl.verifyhost=FALSE, ssl.verifypeer=FALSE))
           con <- file(temp_file, open = "wb")
           writeBin(bin, con)
@@ -324,6 +335,7 @@ download <- function(path=NULL, name=options()$tabs.datasetNames, autoupdate=FAL
   return(url)
 }
 
+
 #' @title Setup - Download of default datasets
 #' @description download default datasets (labs, topo, curve) in default or custom directory. The datasets require 15 GB disk space. 
 #' 
